LoggingRegistry class
Constructors
- LoggingRegistry()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerLogger(
LogLevel level, dynamic logger(Object?)) → void -
toString(
) → String -
A string representation of this object.
inherited
-
useLogging(
LogLevel level, Object? object) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited